@@ -182,11 +182,11 @@ App::Licensecheck - functions for a simple license checker for source files
 
 =head1 VERSION
 
-Version v3.2.4
+Version v3.2.5
 
 =cut
 
-our $VERSION = version->declare('v3.2.4');
+our $VERSION = version->declare('v3.2.5');
 
 =head1 SYNOPSIS
 
@@ -571,6 +571,8 @@ sub clean_cruft
 {
 	local $_ = shift or return q{};
 
+	s/\/?<(?:p|br)>//gi;
+
 	# TODO: decode latin1/UTF-8/HTML data instead
 	s/\xcb\x97|\xe2\x80[\x90-\x95|\xe2\x81\x83|\xe2\x88\x92|\xef\x89\xa3|\xef\xbc\x8d]|[&](?:ndash|mdash|horbar|minus|[#](?:727|820[8-9]|821[0-3]|8259|8722|65123|65293|x727|z201[0-5]|x2043|x2212|xFE63|xFF0D))[;]/-/gm;
 	s/\x58\xa9|\xc2\xa9|\xe2\x92\x9e|\xe2\x92\xb8|\xe2\x93\x92|\xf0\x9f\x84\x92|\xf0\x9f\x84\xab|\xf0\x9f\x85\x92|[&](?:copy|[#](?:169|9374|9400|9426|127250|127275|127314|x0A9|x249E|x24b8|x24D2|x0F112|x0F12B|x0F152))[;]/©/gm;
@@ -587,7 +589,9 @@ sub clean_cruft_and_spaces
 
 	# strip trailing dash, assuming it is soft-wrap
 	# (example: disclaimers in GNU autotools file "install-sh")
-	s/-\r?\n//;
+	s/-\r?\n//g;
+
+	s/\/?<(?:p|br)>//gi;
 
 	tr/\t\r\n/ /;
 
